@@ -187,7 +187,7 @@ def qlCallabilitySchedule_from_class(call_schedule: List[pym.CallabilityPrice]):
     return callability_schedule
 
 
-
-        
+def create_overnightindex():
+    pass        
 
         
\ No newline at end of file
